@@ -1,14 +1,10 @@
 """Command-line interface for entry points"""
 
-from __future__ import absolute_import
-from __future__ import unicode_literals
-
 import logging
 import os
 import sys
 import time
 
-from future.utils import raise_from
 import urllib3
 
 import isilon_hadoop_tools
@@ -17,7 +13,7 @@ import isilon_hadoop_tools.directories
 import isilon_hadoop_tools.identities
 
 
-DRY_RUN = 'Had this been for real, this is what would have happened...'
+DRY_RUN = "Had this been for real, this is what would have happened..."
 LOGGER = logging.getLogger(__name__)
 
 
@@ -26,26 +22,26 @@ def base_cli(parser=None):
     if parser is None:
         parser = isilon_hadoop_tools.cli.base_cli()
     parser.add_argument(
-        '--append-cluster-name',
-        help='the cluster name to append on identities',
+        "--append-cluster-name",
+        help="the cluster name to append on identities",
         type=str,
     )
     parser.add_argument(
-        '--dist',
-        help='the Hadoop distribution to be deployed',
-        choices=('cdh', 'cdp', 'hdp'),
+        "--dist",
+        help="the Hadoop distribution to be deployed",
+        choices=("cdh", "cdp", "hdp"),
         required=True,
     )
     parser.add_argument(
-        '--dry',
-        help='do a dry run (only logs)',
-        action='store_true',
+        "--dry",
+        help="do a dry run (only logs)",
+        action="store_true",
         default=False,
     )
     parser.add_argument(
-        '--version',
-        action='version',
-        version='%(prog)s v{0}'.format(isilon_hadoop_tools.__version__),
+        "--version",
+        action="version",
+        version=f"%(prog)s v{isilon_hadoop_tools.__version__}",
     )
     return parser
 
@@ -61,20 +57,20 @@ def isilon_create_users_cli(parser=None):
     if parser is None:
         parser = base_cli()
     parser.add_argument(
-        '--start-gid',
-        help='the lowest GID to create a group with',
+        "--start-gid",
+        help="the lowest GID to create a group with",
         type=int,
         default=isilon_hadoop_tools.identities.Creator.default_start_gid,
     )
     parser.add_argument(
-        '--start-uid',
-        help='the lowest UID to create a user with',
+        "--start-uid",
+        help="the lowest UID to create a user with",
         type=int,
         default=isilon_hadoop_tools.identities.Creator.default_start_uid,
     )
     parser.add_argument(
-        '--user-password',
-        help='the password for users created',
+        "--user-password",
+        help="the password for users created",
         type=str,
         default=None,
     )
@@ -94,22 +90,26 @@ def isilon_create_users(argv=None):
     onefs = isilon_hadoop_tools.cli.hdfs_client(args)
 
     identities = {
-        'cdh': isilon_hadoop_tools.identities.cdh_identities,
-        'cdp': isilon_hadoop_tools.identities.cdp_identities,
-        'hdp': isilon_hadoop_tools.identities.hdp_identities,
+        "cdh": isilon_hadoop_tools.identities.cdh_identities,
+        "cdp": isilon_hadoop_tools.identities.cdp_identities,
+        "hdp": isilon_hadoop_tools.identities.hdp_identities,
     }[args.dist](args.zone)
 
-    name = '-'.join([
-        str(int(time.time())),
-        args.zone,
-        args.dist,
-    ])
+    name = "-".join(
+        [
+            str(int(time.time())),
+            args.zone,
+            args.dist,
+        ]
+    )
 
     if args.append_cluster_name is not None:
         suffix = args.append_cluster_name
-        if not suffix.startswith('-'):
-            suffix = '-' + suffix
-        identities = isilon_hadoop_tools.identities.with_suffix_applied(identities, suffix)
+        if not suffix.startswith("-"):
+            suffix = "-" + suffix
+        identities = isilon_hadoop_tools.identities.with_suffix_applied(
+            identities, suffix
+        )
         name += suffix
 
     onefs_and_files = isilon_hadoop_tools.identities.Creator(
@@ -117,13 +117,15 @@ def isilon_create_users(argv=None):
         onefs_zone=args.zone,
         start_uid=args.start_uid,
         start_gid=args.start_gid,
-        script_path=os.path.join(os.getcwd(), name + '.sh'),
+        script_path=os.path.join(os.getcwd(), name + ".sh"),
         user_password=args.user_password,
     )
     if args.dry:
         LOGGER.info(DRY_RUN)
-        LOGGER.info('A script would have been created at %s.', onefs_and_files.script_path)
-        LOGGER.info('The following actions would have populated it and OneFS:')
+        LOGGER.info(
+            "A script would have been created at %s.", onefs_and_files.script_path
+        )
+        LOGGER.info("The following actions would have populated it and OneFS:")
         onefs_and_files.log_identities(identities)
     else:
         onefs_and_files.create_identities(identities)
@@ -149,13 +151,13 @@ def isilon_create_directories(argv=None):
     onefs = isilon_hadoop_tools.cli.hdfs_client(args)
 
     suffix = args.append_cluster_name
-    if suffix is not None and not suffix.startswith('-'):
-        suffix = '-' + suffix
+    if suffix is not None and not suffix.startswith("-"):
+        suffix = "-" + suffix
 
     directories = {
-        'cdh': isilon_hadoop_tools.directories.cdh_directories,
-        'cdp': isilon_hadoop_tools.directories.cdp_directories,
-        'hdp': isilon_hadoop_tools.directories.hdp_directories,
+        "cdh": isilon_hadoop_tools.directories.cdh_directories,
+        "cdp": isilon_hadoop_tools.directories.cdp_directories,
+        "hdp": isilon_hadoop_tools.directories.hdp_directories,
     }[args.dist](identity_suffix=suffix)
 
     creator = isilon_hadoop_tools.directories.Creator(
@@ -169,9 +171,6 @@ def isilon_create_directories(argv=None):
         else:
             creator.create_directories(directories)
     except isilon_hadoop_tools.directories.HDFSRootDirectoryError as exc:
-        raise_from(
-            isilon_hadoop_tools.cli.CLIError(
-                'The HDFS root directory must not be {0}.'.format(exc),
-            ),
-            exc,
-        )
+        raise isilon_hadoop_tools.cli.CLIError(
+            f"The HDFS root directory must not be {exc}."
+        ) from exc
